﻿// Copyright (c) Pixel Crushers. All rights reserved.

using UnityEngine;
using UnityEditor;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Custom inspector for IconQuestContent assets.
    /// </summary>
    [CustomEditor(typeof(ORKIconQuestContent), true)]
    public class ORKIconQuestUIContentEditor : QuestSubassetEditor
    {

        protected override void Draw()
        {
            if (serializedObject == null) return;
            EditorGUILayout.HelpBox("Allows an icon to show its count value using an ORK variable.", MessageType.None);
            var imageProperty = serializedObject.FindProperty("m_image");
            var captionProperty = serializedObject.FindProperty("m_caption");
            var countProperty = serializedObject.FindProperty("m_count");
            var useVariableProperty = serializedObject.FindProperty("m_useVariable");
            var orkVariableProperty = serializedObject.FindProperty("m_ORKVariable");
            var globalVariableProperty = serializedObject.FindProperty("m_globalVariable");
            var objectIDProperty = serializedObject.FindProperty("m_objectID");
            if (imageProperty != null) EditorGUILayout.PropertyField(imageProperty, true);
            if (captionProperty != null) EditorGUILayout.PropertyField(captionProperty, true);
            if (useVariableProperty != null) EditorGUILayout.PropertyField(useVariableProperty, true);
            if (useVariableProperty.boolValue)
            {
                if (orkVariableProperty != null) EditorGUILayout.PropertyField(orkVariableProperty, true);
                if (globalVariableProperty != null) EditorGUILayout.PropertyField(globalVariableProperty, true);
                if (!globalVariableProperty.boolValue)
                {
                    if (objectIDProperty != null) EditorGUILayout.PropertyField(objectIDProperty, true);
                }
            }
            else
            {
                if (countProperty != null) EditorGUILayout.PropertyField(countProperty, true);
            }
        }

    }
}
