﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Gives currency to the ORK player equal to the point value of the quest.
    /// </summary>
    [AddComponentMenu("Pixel Crushers/Quest Machine/Third Party/ORK Framework/Generator/ORK Currency Reward System")]
    public class ORKCurrencyRewardSystem : RewardSystem
    {

        public StringField currencyName = new StringField();

        public override int DetermineReward(int points, Quest quest, EntityType entityType)
        {
            var amount = (entityType != null) ? (int)(points * entityType.GetRewardMultiplier(RewardMultiplier.Currency)) : points;

            var bodyText = BodyTextQuestContent.CreateInstance<BodyTextQuestContent>();
            bodyText.bodyText = new StringField(amount + " " + currencyName);
            quest.offerContentList.Add(bodyText);

            var currencyAction = ORKCurrencyQuestAction.CreateInstance<ORKCurrencyQuestAction>();
            currencyAction.usePlayer = true;
            currencyAction.operation = ORKAddRemoveOperation.Add;
            currencyAction.quantity = new QuestNumber(amount);
            currencyAction.currencyName = new StringField(currencyName);
            var successInfo = quest.GetStateInfo(QuestState.Successful);
            successInfo.actionList.Add(currencyAction);

            return 0;
        }

    }
}