﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Gives EXP or another status value to the ORK player.
    /// </summary>
    [AddComponentMenu("Pixel Crushers/Quest Machine/Third Party/ORK Framework/Generator/ORK Exp Reward System")]
    public class ORKExpRewardSystem : RewardSystem
    {
        [HelpBox("Add points to a status value when the quester completes the quest. Exp is typically ID 11, although it may differ in your project.", HelpBoxMessageType.None)]
        [Tooltip("Status value to add points to. Exp is typically ID 11, although it may differ in your project.")]
        [SerializeField]
        private int m_statusValueID = 11;

        [Tooltip("Show this name for the status value in reward text.")]
        [SerializeField]
        private StringField m_statusValueName = new StringField("EXP");

        public int statusValueID
        {
            get { return m_statusValueID; }
            set { m_statusValueID = value; }
        }

        public StringField statusValueName
        {
            get { return m_statusValueName; }
            set { m_statusValueName = value; }
        }

        public override int DetermineReward(int points, Quest quest, EntityType entityType)
        {
            var amount = (entityType != null) ? (int)(points * entityType.GetRewardMultiplier(RewardMultiplier.XP)) : points;

            var bodyText = BodyTextQuestContent.CreateInstance<BodyTextQuestContent>();
            bodyText.bodyText = new StringField(amount + " " + StringField.GetStringValue(statusValueName));
            quest.offerContentList.Add(bodyText);

            var expAction = ORKGiveExpQuestAction.CreateInstance<ORKGiveExpQuestAction>();
            expAction.usePlayer = true;
            expAction.statusValueID = statusValueID;
            expAction.exp = new QuestNumber(amount);
            var successInfo = quest.GetStateInfo(QuestState.Successful);
            successInfo.actionList.Add(expAction);

            return points;
        }

    }
}