﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to generate a quest.
    /// </summary>
    [ORKEditorHelp("Generate Quest", "Tells a quest generator to start generating a quest.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/UI")]
    public class GenerateQuestStep : BaseEventStep
    {

        [ORKEditorHelp("Quest Generator", "Select the quest generator to generate a quest.", "")]
        [ORKEditorInfo(labelText = "Quest Generator")]
        public EventObjectSetting generatorObject = new EventObjectSetting();

        public override void Execute(BaseEvent baseEvent)
        {
            var list = generatorObject.GetObject(baseEvent);
            var generator = ((list != null) && (list.Count > 0)) ? list[0].transform.GetComponent<QuestGeneratorEntity>() : null;
            if (generator == null)
            {
                Debug.LogWarning("Quest Machine: Can't find quest generator entity to generate a quest.");
            }
            else
            {
                if (QuestMachine.debug) Debug.Log("Quest Machine: " + generator.name + " generating a quest.", generator);
                generator.GenerateQuest();
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
