﻿using UnityEngine;
using PixelCrushers;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to set a quest node state.
    /// </summary>
    [ORKEditorHelp("Send To Message System", "Sends a message to Quest Machine's Message System.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/Message System")]
    public class SendToMessageSystemStep : BaseEventStep
    {

        [ORKEditorHelp("Message", "Message to send.", "")]
        [ORKEditorInfo(labelText = "Message")]
        public StringValue message = new StringValue();

        [ORKEditorHelp("Parameter", "Parameter to send with message.", "")]
        [ORKEditorInfo(labelText = "Parameter")]
        public StringValue parameter = new StringValue();

        [ORKEditorHelp("Sender", "Sender (optional).", "")]
        [ORKEditorInfo(labelText = "Sender")]
        public EventObjectSetting senderObject = new EventObjectSetting();

        [ORKEditorHelp("Target", "Target (optional).", "")]
        [ORKEditorInfo(labelText = "Target")]
        public EventObjectSetting targetObject  = new EventObjectSetting();

        public override void Execute(BaseEvent baseEvent)
        {
            var list = senderObject.GetObject(baseEvent);
            var sender = ((list != null) && (list.Count > 0)) ? list[0] : null;
            list = senderObject.GetObject(baseEvent);
            var target = ((list != null) && (list.Count > 0)) ? list[0] : null;
            MessageSystem.SendMessageWithTarget(sender, target, message.GetValue(), parameter.GetValue());
            baseEvent.StepFinished(this.next);
        }

        public override string GetNodeDetails()
        {
            return message.value + " " + parameter.value;
        }

    }
}
