﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to start dialogue with a quest giver and the player.
    /// </summary>
    [ORKEditorHelp("Give Quest", "Gives a quest to the player.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/Quest Control")]
    public class GiveQuestStep : BaseEventStep
    {

        [ORKEditorHelp("Quest Giver", "Select the quest giver who is giving the quest.", "")]
        [ORKEditorInfo(labelText = "Quest Giver")]
        public EventObjectSetting giverObject = new EventObjectSetting();

        [ORKEditorHelp("Give All Quests", "Give all of the quest giver's quests to the player.", "")]
        [ORKEditorInfo(labelText = "Give All Quests")]
        public bool giveAllQuests = false;

        [ORKEditorHelp("Quest ID", "If Give All Quests is unticked, give this quest.", "")]
        [ORKEditorInfo(labelText = "Quest ID")]
        public StringValue questID = new StringValue();

        public override void Execute(BaseEvent baseEvent)
        {
            var list = giverObject.GetObject(baseEvent);
            var giver = ((list != null) && (list.Count > 0)) ? list[0].transform.GetComponent<QuestGiver>() : null;
            if (giver == null)
            {
                Debug.LogWarning("Quest Machine: Can't find quest giver to give quest.");
            }
            else
            {
                var journal = GameObject.FindObjectOfType<QuestJournal>();
                if (journal == null)
                {
                    Debug.LogWarning("Quest Machine: Can't find quest journal to give quest.");
                }
                else
                {
                    var questerTextInfo = new QuestParticipantTextInfo(QuestMachineMessages.GetID(journal), QuestMachineMessages.GetDisplayName(journal), null, null);
                    if (giveAllQuests)
                    {
                        if (QuestMachine.debug) Debug.Log("Quest Machine: Giving all quests to player.", giver);
                        giver.GiveAllQuestsToQuester(journal);
                    }
                    else
                    {
                        var quest = giver.questList.Find(x => Equals(x.id, questID.GetValue()));
                        if (quest == null)
                        {
                            Debug.LogWarning("Quest Machine: Can't give quest. No quest with ID '" + questID + "' found on " + giver, giver);
                        }
                        else
                        {
                            if (QuestMachine.debug) Debug.Log("Quest Machine: Giving quest with ID '" + questID + "' to player.", giver);
                            giver.GiveQuestToQuester(quest, questerTextInfo, journal);
                        }
                    }
                }
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
