﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to start dialogue with a quest giver and the player.
    /// </summary>
    [ORKEditorHelp("Set Quest Counter", "Sets a quest counter value.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/Quest Control")]
    public class SetQuestCounterStep : BaseEventStep
    {

        [ORKEditorHelp("Quest ID", "Set the counter in this quest.", "")]
        [ORKEditorInfo(labelText = "Quest ID")]
        public StringValue questID = new StringValue();

        [ORKEditorHelp("Counter Name", "Set this counter.", "")]
        [ORKEditorInfo(labelText = "Counter Name")]
        public StringValue counterName = new StringValue();

        public enum Mode { Set, Add }

        public Mode mode = Mode.Add;

        [ORKEditorHelp("Amount", "The amount to set/add to the counter.", "")]
        [ORKEditorInfo(labelText = "Amount")]
        public int amount = 1;

        public override void Execute(BaseEvent baseEvent)
        {
            var quest = QuestMachine.GetQuestInstance(questID.GetValue());
            if (quest == null)
            {
                Debug.LogWarning("Quest Machine: Can't find quest '" + questID + "' to set counter " + counterName + ".");
            }
            else
            {
                var counter = quest.GetCounter(counterName.GetValue());
                if (counter == null)
                {
                    Debug.LogWarning("Quest Machine: Can't find a counter named '" + counterName + "' in quest '" + questID + "' .");
                }
                else
                {
                    switch (mode)
                    {
                        case Mode.Set: counter.currentValue = amount; break;
                        case Mode.Add: counter.currentValue += amount; break;
                    }
                }
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
