﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to set a quest node state.
    /// </summary>
    [ORKEditorHelp("Set Quest Node State", "Sets a quest node state.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/Quest Control")]
    public class SetQuestNodeStateStep : BaseEventStep
    {

        [ORKEditorHelp("Quest ID", "Quest ID.", "")]
        [ORKEditorInfo(labelText = "Quest ID")]
        public StringValue questID = new StringValue();

        [ORKEditorHelp("Quest Node ID", "Quest Node ID in the quest.", "")]
        [ORKEditorInfo(labelText = "Quest Node ID")]
        public StringValue questNodeID = new StringValue();
        
        [ORKEditorHelp("State", "New quest node state.", "")]
        [ORKEditorInfo(labelText = "State")]
        public QuestNodeState state;

        public override void Execute(BaseEvent baseEvent)
        {
            var questIDValue = questID.GetValue();
            var questNodeIDValue = questNodeID.GetValue();
            if (string.IsNullOrEmpty(questIDValue))
            {
                Debug.LogWarning("Quest Machine: Quest ID is null. Can't set quest node state.");
            }
            else if (string.IsNullOrEmpty(questNodeIDValue))
            {
                Debug.LogWarning("Quest Machine: Quest node ID is null. Can't set quest node state.");
            }
            else
            {
                QuestMachine.SetQuestNodeState(questIDValue, questNodeIDValue, state);
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
