﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to set a quest node state.
    /// </summary>
    [ORKEditorHelp("Set Quest State", "Sets a quest state.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/Quest Control")]
    public class SetQMQuestStateStep : BaseEventStep
    {

        [ORKEditorHelp("Quest ID", "Quest ID.", "")]
        [ORKEditorInfo(labelText = "Quest ID")]
        public StringValue questID = new StringValue();

        [ORKEditorHelp("State", "New quest state.", "")]
        [ORKEditorInfo(labelText = "State")]
        public QuestState state;

        public override void Execute(BaseEvent baseEvent)
        {
            if (string.IsNullOrEmpty(questID.GetValue()))
            {
                Debug.LogWarning("Quest Machine: Quest ID is null. Can't set quest state.");
            }
            else
            {
                QuestMachine.SetQuestState(questID.GetValue(), state);
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
