﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to control a Quest Machine spawner.
    /// </summary>
    [ORKEditorHelp("Control Spawner", "Controls a spawner.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/Spawner")]
    public class ControlSpawnerStep : BaseEventStep
    {

        [ORKEditorHelp("Spawner", "Select the spawner to control.", "")]
        [ORKEditorInfo(labelText = "Spawner")]
        public EventObjectSetting spawnerObject = new EventObjectSetting();

        public enum Mode { Start, Stop }

        public Mode mode;

        public override void Execute(BaseEvent baseEvent)
        {
            var list = spawnerObject.GetObject(baseEvent);
            var spawner = ((list != null) && (list.Count > 0)) ? list[0].transform.GetComponent<Spawner>() : null;
            if (spawner == null)
            {
                Debug.LogWarning("Quest Machine: Can't find spawner.");
            }
            else
            {
                if (QuestMachine.debug) Debug.Log("Quest Machine: " + mode + " spawner " + spawner.name + ".", spawner);
                switch (mode)
                {
                    case Mode.Start:
                        spawner.StartSpawning();
                        break;
                    case Mode.Stop:
                        spawner.StopSpawning();
                        break;
                }
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
