﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to toggle the quest journal UI.
    /// </summary>
	[ORKEditorHelp("Set HUD", "Sets the HUD visibility.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/UI")]
    public class SetHUDStep : BaseEventStep
    {

        public enum Mode { Show, Hide, Toggle }

        public Mode mode;

        public bool closeORKMenus = true;

        public override void Execute(BaseEvent baseEvent)
        {
            if (QuestMachine.debug) Debug.Log("Quest Machine: " + mode + " quest HUD.");
            if (closeORKMenus) ORK.Menu.CloseAllMenus(true);
            var containerEntity = GameObject.FindObjectOfType<QuestJournal>();
            var hud = QuestMachine.defaultQuestHUD;
            if (hud != null)
            {
                switch (mode)
                {
                    case Mode.Show:
                        hud.Show(containerEntity);
                        break;
                    case Mode.Hide:
                        hud.Hide();
                        break;
                    case Mode.Toggle:
                        hud.Toggle(containerEntity);
                        break;
                }
            }
            baseEvent.StepFinished(this.next);
        }
    }
}