﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to toggle the quest journal UI.
    /// </summary>
	[ORKEditorHelp("Set Journal UI", "Sets the quest journal visibility.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/UI")]
    public class SetJournalUIStep : BaseEventStep
    {

        public enum Mode { Show, Hide, Toggle }

        public Mode mode;

        public bool closeORKMenus = true;

        public override void Execute(BaseEvent baseEvent)
        {
            if (QuestMachine.debug) Debug.Log("Quest Machine: " + mode + " quest journal UI.");
            var journal = GameObject.FindObjectOfType<QuestJournal>();
            if (journal != null)
            {
                if (closeORKMenus) ORK.Menu.CloseAllMenus(true);
                switch (mode)
                {
                    case Mode.Show:
                        journal.ShowJournalUI();
                        break;
                    case Mode.Hide:
                        journal.HideJournalUI();
                        break;
                    case Mode.Toggle:
                        journal.ToggleJournalUI();
                        break;
                }
                baseEvent.StepFinished(this.next);
            }
        }
    }
}