﻿using UnityEngine;
using PixelCrushers.QuestMachine;

namespace ORKFramework.Events.Steps
{

    /// <summary>
    /// ORK event to start dialogue with a quest giver and the player.
    /// </summary>
    [ORKEditorHelp("Start Dialogue", "Starts dialogue with a quest giver.", "")]
    [ORKEventStep(typeof(BaseEvent))]
    [ORKNodeInfo("Quest Machine/UI")]
    public class StartDialogueStep : BaseEventStep
    {

        [ORKEditorHelp("Quest Giver", "Select the quest giver to start dialogue with.", "")]
        [ORKEditorInfo(labelText = "Quest Giver")]
        public EventObjectSetting giverObject = new EventObjectSetting();

        public override void Execute(BaseEvent baseEvent)
        {
            var list = giverObject.GetObject(baseEvent);
            var giver = ((list != null) && (list.Count > 0)) ? list[0].transform.GetComponent<QuestGiver>() : null;
            if (giver == null)
            {
                Debug.LogWarning("Quest Machine: Can't find quest giver to start dialogue.");
            }
            else
            {
                if (QuestMachine.debug) Debug.Log("Quest Machine: Starting dialogue with " + giver.name + ".", giver);
                giver.StartDialogueWithPlayer();
            }
            baseEvent.StepFinished(this.next);
        }

    }
}
