﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest action that gives or takes currency from a combatant.
    /// </summary>
    public class ORKCurrencyQuestAction : ORKCombatantQuestAction
    {

        // Inherited:
        // usePlayer
        // combatantName

        [SerializeField]
        private ORKAddRemoveOperation m_operation = ORKAddRemoveOperation.Add;

        [SerializeField]
        private QuestNumber m_quantity = new QuestNumber(1);

        [SerializeField]
        private StringField m_currencyName = new StringField();

        public ORKAddRemoveOperation operation
        {
            get { return m_operation; }
            set { m_operation = value; }
        }

        public QuestNumber quantity
        {
            get { return m_quantity; }
            set { m_quantity = value; }
        }

        public StringField currencyName
        {
            get { return m_currencyName; }
            set { m_currencyName = value; }
        }

        public override void Execute()
        {
            base.Execute();
            var combatant = ORKUtility.GetCombatant(runtimeCombatantName);
            if (combatant == null)
            {
                if (Debug.isDebugBuild) Debug.LogWarning("Quest Machine: ORK Currency action can't find " + runtimeCombatantName + " combatant.");
            }
            else
            {
                var currencyIndex = ORKUtility.GetCurrencyIndex(StringField.GetStringValue(currencyName));
                var currentAmount = ORKUtility.ORKGetMoney(combatant, currencyIndex);
                var newAmount = currentAmount + ((operation == ORKAddRemoveOperation.Add) ? 1 : -1) * quantity.GetValue(quest);
                ORKUtility.ORKSetMoney(runtimeCombatantName, StringField.GetStringValue(currencyName), newAmount);
            }
        }

        public override string GetEditorName()
        {
            return operation + " " + quantity.literalValue + " " + StringField.GetStringValue(currencyName) +
                ((operation == ORKAddRemoveOperation.Add) ? " to " : " from ") + runtimeCombatantName;
        }

    }

}
