﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using ORKFramework.Behaviours;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest action that starts an ORK event.
    /// </summary>
    public class ORKEventQuestAction : QuestAction
    {

        [SerializeField]
        private StringField m_eventInteractionID = new StringField();

        [Tooltip("Event asset to run on the EventInteraction who matches the ID above.")]
        [SerializeField]
        private ORKGameEvent m_eventAsset;

        [SerializeField]
        private StringField m_startingObjectID = new StringField();

        public StringField eventInteractionID
        {
            get { return m_eventInteractionID; }
            set { m_eventInteractionID = value; }
        }

        public StringField runtimeEventInteractionID
        {
            get { return !StringField.IsNullOrEmpty(eventInteractionID) ? eventInteractionID : quest.questGiverID; }
        }

        public ORKGameEvent eventAsset
        {
            get { return m_eventAsset; }
            set { m_eventAsset = value; }
        }

        public StringField startingObjectID
        {
            get { return m_startingObjectID; }
            set { m_startingObjectID = value; }
        }

        public override void Execute()
        {
            base.Execute();
            var go = QuestMachineMessages.FindGameObjectWithID(runtimeEventInteractionID);
            if (go == null)
            {
                if (Debug.isDebugBuild) Debug.LogWarning("Quest Machine: OrkEventQuestAction can't find a GameObject with ID " + runtimeEventInteractionID + ".");
                return;
            }
            var eventInteraction = go.GetComponent<EventInteraction>() ?? go.AddComponent<EventInteraction>();
            eventInteraction.eventAsset = eventAsset;
            var startingGO = StringField.IsNullOrEmpty(startingObjectID) ? go : QuestMachineMessages.FindGameObjectWithID(startingObjectID);
            eventInteraction.StartEvent(startingGO);
        }

        public override string GetEditorName()
        {
            if (!StringField.IsNullOrEmpty(eventInteractionID) && eventAsset != null && !StringField.IsNullOrEmpty(startingObjectID))
            {
                return "Start ORK event " + eventAsset.name + " on " + eventInteractionID + " with object " + startingObjectID;
            }
            else if (!StringField.IsNullOrEmpty(eventInteractionID) && eventAsset != null)
            {
                return "Start ORK event " + eventAsset.name + " on " + eventInteractionID;
            }
            else if (!StringField.IsNullOrEmpty(eventInteractionID))
            {
                return "Start ORK event (unspecified) on " + eventInteractionID;
            }
            if (StringField.IsNullOrEmpty(eventInteractionID) && eventAsset != null && !StringField.IsNullOrEmpty(startingObjectID))
            {
                return "Start ORK event " + eventAsset.name + " on quest giver with object " + startingObjectID;
            }
            else if (eventAsset != null)
            {
                return "Start ORK event " + eventAsset.name + " on quest giver";
            }
            else
            {
                return "Start ORK event";
            }
        }

    }

}
