﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using UnityEngine.Serialization;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest action that gives XP or another status value to a combatant.
    /// </summary>
    public class ORKGiveExpQuestAction : ORKCombatantQuestAction
    {

        // Inherited:
        // usePlayer
        // combatantName

        [Tooltip("Status value to add points to. Exp is typically ID 11, although it may differ in your project.")]
        [SerializeField]
        private int m_statusValueID = 11; // Typically EXP value.

        [Tooltip("Amount to add to status value.")]
        [SerializeField]
        [FormerlySerializedAs("m_exp")]
        private QuestNumber m_amount = new QuestNumber(0);

        [Tooltip("Show ORK notification.")]
        [SerializeField]
        private bool m_showNotification = false;

        [Tooltip("Show in ORK console.")]
        [SerializeField]
        private bool m_showConsole = false;

        public int statusValueID
        {
            get { return m_statusValueID; }
            set { m_statusValueID = value; }
        }

        public QuestNumber amount
        {
            get { return m_amount; }
            set { m_amount = value; }
        }

        public QuestNumber exp
        {
            get { return amount; }
            set { amount = value; }
        }

        public bool showNotification
        {
            get { return m_showNotification; }
            set { m_showNotification = value; }
        }

        public bool showConsole
        {
            get { return m_showConsole; }
            set { m_showConsole = value; }
        }

        public override void Execute()
        {
            base.Execute();
            var combatant = ORKUtility.GetCombatant(runtimeCombatantName);
            if (combatant == null)
            {
                if (Debug.isDebugBuild) Debug.LogWarning("Quest Machine: ORK Give EXP can't find " + runtimeCombatantName + " combatant.");
            }
            else
            {
                var value = exp.GetValue(quest);
                if (QuestMachine.debug) Debug.Log("Quest Machine: Give " + value + " of status value ID " + statusValueID + " to " + runtimeCombatantName + ".");
                var statusValue = combatant.Status[statusValueID];
                statusValue.AddValue(value, false, false, true, false, showNotification, showConsole, new ORKFramework.StatusValueChangeSource(null, combatant));
            }
        }

        public override string GetEditorName()
        {
            return "Give " + exp.literalValue + " of status value ID " + statusValueID + " to " + runtimeCombatantName;
        }

    }

}
