﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest action that gives or takes an item from a combatant.
    /// </summary>
    public class ORKItemQuestAction : ORKCombatantQuestAction
    {

        // Inherited:
        // usePlayer
        // combatantName

        [SerializeField]
        private ORKAddRemoveOperation m_operation = ORKAddRemoveOperation.Add;

        [SerializeField]
        private QuestNumber m_quantity = new QuestNumber(1);

        [SerializeField]
        private StringField m_itemName = new StringField();

        public ORKAddRemoveOperation operation
        {
            get { return m_operation; }
            set { m_operation = value; }
        }

        public QuestNumber quantity
        {
            get { return m_quantity; }
            set { m_quantity = value; }
        }

        public StringField itemName
        {
            get { return m_itemName; }
            set { m_itemName = value; }
        }

        public override void Execute()
        {
            base.Execute();
            var combatant = ORKUtility.GetCombatant(runtimeCombatantName);
            if (combatant == null)
            {
                if (Debug.isDebugBuild) Debug.LogWarning("Quest Machine: ORK Item action can't find " + runtimeCombatantName + " combatant.");
            }
            else
            {
                switch (operation)
                {
                    case ORKAddRemoveOperation.Add:
                        ORKUtility.ORKAddItemQuantity(runtimeCombatantName, StringField.GetStringValue(itemName), quantity.GetValue(quest));
                        break;
                    case ORKAddRemoveOperation.Remove:
                        ORKUtility.ORKRemoveItemQuantity(runtimeCombatantName, StringField.GetStringValue(itemName), quantity.GetValue(quest));
                        break;
                }                
            }
        }

        public override string GetEditorName()
        {
            return operation + " " + quantity.literalValue + " " + StringField.GetStringValue(itemName) + 
                ((operation == ORKAddRemoveOperation.Add) ? " to " : " from ") + runtimeCombatantName;
        }

    }

}
