﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using ORKFramework;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest action that sets an ORK variable.
    /// </summary>
    public class ORKSetVariableQuestAction : QuestAction
    {

        [SerializeField]
        private bool m_globalVariable = true;

        [SerializeField]
        private StringField m_objectID = new StringField();

        [SerializeField]
        private StringField m_key = new StringField();

        [SerializeField]
        private ORKUtilityVariableType m_variableType;

        [SerializeField]
        private ORKUtilityBoolValue m_boolValue;

        [SerializeField]
        private QuestNumber m_intValue = new QuestNumber(1);

        public bool globalVariable
        {
            get { return m_globalVariable; }
            set { m_globalVariable = value; }
        }

        public StringField objectID
        {
            get { return m_objectID; }
            set { m_objectID = value; }
        }

        public StringField key
        {
            get { return m_key; }
            set { m_key = value; }
        }

        public ORKUtilityVariableType variableType
        {
            get { return m_variableType; }
            set { m_variableType = value; }
        }

        public ORKUtilityBoolValue boolValue
        {
            get { return m_boolValue; }
            set { m_boolValue = value; }
        }

        public QuestNumber intValue
        {
            get { return m_intValue; }
            set { m_intValue = value; }
        }

        private VariableHandler variableHandler
        {
            get { return globalVariable ? ORK.Game.Variables : ORK.Game.Scene.GetObjectVariables(StringField.GetStringValue(objectID)); }
        }

        private StringValue m_keyStringValue = null;
        private StringValue keyStringValue
        {
            get
            {
                if (m_keyStringValue == null) m_keyStringValue = new StringValue(StringField.GetStringValue(key));
                return m_keyStringValue;
            }
        }

        public override void Execute()
        {
            base.Execute();
            switch (variableType)
            {
                case ORKUtilityVariableType.Bool:
                    ORKUtility.SetVariableValue(variableHandler, (boolValue == ORKUtilityBoolValue.True), keyStringValue);
                    break;
                case ORKUtilityVariableType.Int:
                    ORKUtility.SetVariableValue(variableHandler, intValue.GetValue(quest), keyStringValue);
                    break;
            }
        }

        public override string GetEditorName()
        {
            var s = "Set ORK " + (globalVariable ? "global" : StringField.GetStringValue(objectID)) + " " + key;
            switch (variableType)
            {
                case ORKUtilityVariableType.Bool:
                    return s + " to " + boolValue;
                case ORKUtilityVariableType.Int:
                    return s + " to " + intValue.literalValue;
                default:
                    return s;
            }
        }

    }

}
