﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using ORKFramework;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Base class for quest conditions that check something on a combatant.
    /// </summary>
    public abstract class ORKCombatantQuestCondition : QuestCondition, IQuestTimer
    {

        [SerializeField]
        private bool m_checkPlayer = true;

        [SerializeField]
        private StringField m_combatantName = new StringField();

        public bool checkPlayer
        {
            get { return m_checkPlayer; }
            set { m_checkPlayer = value; }
        }

        public StringField combatantName
        {
            get { return m_combatantName; }
            set { m_combatantName = value; }
        }

        private Combatant m_combatant = null;
        protected Combatant combatant
        {
            get
            {
                if (m_combatant == null) m_combatant = (checkPlayer || StringField.IsNullOrEmpty(combatantName)) ? ORK.Game.ActiveGroup.Leader : ORKUtility.GetCombatant(StringField.GetStringValue(combatantName));
                return m_combatant;
            }
        }

        protected bool usePlayer { get { return checkPlayer || StringField.IsNullOrEmpty(combatantName); } }

        protected string runtimeCombatantName { get { return usePlayer ? "player" : StringField.GetStringValue(combatantName); } }

        public override void StartChecking(System.Action trueAction)
        {
            base.StartChecking(trueAction);
            if (IsConditionMet())
            {
                SetTrue();
            }
            else
            {
                QuestTimerManager.RegisterTimer(this);
            }
        }

        public override void StopChecking()
        {
            base.StopChecking();
            QuestTimerManager.UnregisterTimer(this);
        }

        public void Tick()
        {
            if (IsConditionMet())
            {
                StopChecking();
                SetTrue();
            }
        }

        protected abstract bool IsConditionMet();

    }

}
