﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest condition that checks a combatant's currency.
    /// </summary>
    public class ORKHasCurrencyQuestCondition : ORKCombatantQuestCondition
    {

        // Inherited:
        // checkPlayer
        // combatantName

        [SerializeField]
        private CounterValueConditionMode m_criterion = CounterValueConditionMode.AtLeast;

        [SerializeField]
        private QuestNumber m_requiredValue = new QuestNumber(1);

        [SerializeField]
        private StringField m_currencyName = new StringField();

        public CounterValueConditionMode criterion
        {
            get { return m_criterion; }
            set { m_criterion = value; }
        }

        public QuestNumber requiredValue
        {
            get { return m_requiredValue; }
            set { m_requiredValue = value; }
        }

        public StringField currencyName
        {
            get { return m_currencyName; }
            set { m_currencyName = value; }
        }

        private int currencyIndex { get; set; }

        private bool m_printedWarning = false;

        public override string GetEditorName()
        {
            return "ORK " + runtimeCombatantName + " has " + criterion + " " + requiredValue.literalValue + " " + currencyName;
        }

        public override void StartChecking(System.Action trueAction)
        {
            currencyIndex = ORKUtility.GetCurrencyIndex(StringField.GetStringValue(currencyName));
            base.StartChecking(trueAction);
        }

        protected override bool IsConditionMet()
        {
            if (combatant == null)
            {
                if (Debug.isDebugBuild && !m_printedWarning) Debug.LogWarning("Quest Machine: ORK Has Currency can't find " + runtimeCombatantName + " combatant.");
                m_printedWarning = true;
                return false;
            }
            switch (criterion)
            {
                default:
                case CounterValueConditionMode.AtLeast:
                    return ORKUtility.ORKGetMoney(combatant, currencyIndex) >= requiredValue.GetValue(quest);
                case CounterValueConditionMode.AtMost:
                    return ORKUtility.ORKGetMoney(combatant, currencyIndex) <= requiredValue.GetValue(quest);
            }
        }

    }

}
