﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest condition that checks a combatant's faction sympathy with another faction.
    /// </summary>
    public class ORKHasFactionSympathyQuestCondition : ORKCombatantQuestCondition
    {

        // Inherited:
        // checkPlayer
        // combatantName

        [SerializeField]
        private CounterValueConditionMode m_criterion = CounterValueConditionMode.AtLeast;

        [SerializeField]
        private QuestNumber m_requiredValue = new QuestNumber(1);

        [SerializeField]
        private StringField m_otherFaction = new StringField();

        public CounterValueConditionMode criterion
        {
            get { return m_criterion; }
            set { m_criterion = value; }
        }

        public QuestNumber requiredValue
        {
            get { return m_requiredValue; }
            set { m_requiredValue = value; }
        }

        public StringField otherFaction
        {
            get { return m_otherFaction; }
            set { m_otherFaction = value; }
        }

        private int otherFactionID { get; set; }

        private bool m_printedWarning = false;

        public override string GetEditorName()
        {
            return "ORK " + runtimeCombatantName + " has " + criterion + " " + requiredValue.literalValue + " faction with " + otherFaction;
        }

        public override void StartChecking(System.Action trueAction)
        {
            otherFactionID = ORKUtility.GetFactionID(StringField.GetStringValue(otherFaction));
            base.StartChecking(trueAction);
        }

        protected override bool IsConditionMet()
        {
            if (combatant == null)
            {
                if (Debug.isDebugBuild && !m_printedWarning) Debug.LogWarning("Quest Machine: ORK Has Faction Sympathy can't find " + runtimeCombatantName + " combatant.");
                m_printedWarning = true;
                return false;
            }
            switch (criterion)
            {
                default:
                case CounterValueConditionMode.AtLeast:
                    return ORKUtility.ORKGetFactionSympathy(combatant.Group.FactionID, otherFactionID) >= requiredValue.GetValue(quest);
                case CounterValueConditionMode.AtMost:
                    return ORKUtility.ORKGetFactionSympathy(combatant.Group.FactionID, otherFactionID) <= requiredValue.GetValue(quest);
            }
        }

    }

}
