﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest condition that checks a combatant's inventory.
    /// </summary>
    public class ORKHasItemQuestCondition : ORKCombatantQuestCondition
    {

        // Inherited:
        // checkPlayer
        // combatantName

        [SerializeField]
        private QuestNumber m_requiredValue = new QuestNumber(1);

        [SerializeField]
        private StringField m_itemName = new StringField();

        public QuestNumber requiredValue
        {
            get { return m_requiredValue; }
            set { m_requiredValue = value; }
        }

        public StringField itemName
        {
            get { return m_itemName; }
            set { m_itemName = value; }
        }

        public override string GetEditorName()
        {
            return "ORK " + runtimeCombatantName + " has " + requiredValue.literalValue + " " + itemName;
        }

        private bool m_printedWarning = false;

        protected override bool IsConditionMet()
        {
            if (combatant == null)
            {
                if (Debug.isDebugBuild && !m_printedWarning) Debug.LogWarning("Quest Machine: ORK Has Item can't find " + runtimeCombatantName + " combatant.");
                m_printedWarning = true;
                return false;
            }
            return ORKUtility.ORKHasItemQuantity(combatant, StringField.GetStringValue(itemName), requiredValue.GetValue(quest));
        }

    }

}
