﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Quest condition that checks a combatant's level.
    /// </summary>
    public class ORKLevelQuestCondition : ORKCombatantQuestCondition
    {

        // Inherited:
        // checkPlayer
        // combatantName

        [SerializeField]
        private CounterValueConditionMode m_criterion = CounterValueConditionMode.AtLeast;

        [SerializeField]
        private QuestNumber m_requiredValue = new QuestNumber(1);

        public CounterValueConditionMode criterion
        {
            get { return m_criterion; }
            set { m_criterion = value; }
        }

        public QuestNumber requiredValue
        {
            get { return m_requiredValue; }
            set { m_requiredValue = value; }
        }

        public override string GetEditorName()
        {
            return "ORK " + runtimeCombatantName + " level " + criterion + " " + requiredValue.literalValue;
        }

        private bool m_printedWarning = false;

        protected override bool IsConditionMet()
        {
            if (combatant == null)
            {
                if (Debug.isDebugBuild && !m_printedWarning) Debug.LogWarning("Quest Machine: ORK Level condition can't find " + runtimeCombatantName + " combatant.");
                m_printedWarning = true;
                return false;
            }
            switch (criterion)
            {
                case CounterValueConditionMode.AtLeast:
                    if (combatant.Class.Level >= requiredValue.GetValue(quest)) return true;
                    break;
                case CounterValueConditionMode.AtMost:
                    if (combatant.Class.Level <= requiredValue.GetValue(quest)) return true;
                    break;
            }
            return false;
        }

    }

}
