﻿// Copyright (c) Pixel Crushers. All rights reserved.

using UnityEngine;
using ORKFramework;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// Icon UI content (image with optional count and caption) with an optional
    /// list of actions. If the list of actions is non-empty, the icon acts as a
    /// button. In this subclass, the count can come from an ORK variable.
    /// </summary>
    public class ORKIconQuestContent : IconQuestContent
    {
        [Tooltip("Get count from ORK variable.")]
        [SerializeField]
        private bool m_useVariable = false;

        [Tooltip("ORK variable for count. If blank, uses Count value above.")]
        [SerializeField]
        private StringField m_ORKVariable;

        [SerializeField]
        private bool m_globalVariable = true;

        [Tooltip("If Global Variable is unticked, specify variable owner here.")]
        [SerializeField]
        private StringField m_objectID = new StringField();

        public bool useVariable
        {
            get { return m_useVariable; }
            set { m_useVariable = value; }
        }

        public bool globalVariable
        {
            get { return m_globalVariable; }
            set { m_globalVariable = value; }
        }

        public StringField objectID
        {
            get { return m_objectID; }
            set { m_objectID = value; }
        }

        private VariableHandler variableHandler
        {
            get { return globalVariable ? ORK.Game.Variables : ORK.Game.Scene.GetObjectVariables(StringField.GetStringValue(objectID)); }
        }

        /// <summary>
        /// The count to show on the count label. If 0 or 1, count is not shown.
        /// </summary>
        public override int count
        {
            get 
            {
                return useVariable ? ORKUtility.GetVariableIntValue(variableHandler, StringField.GetStringValue(m_ORKVariable)) : base.count;
            }
            set 
            { 
                base.count = value;
                m_ORKVariable.value = string.Empty;
            }
        }

        public override string GetEditorName()
        {
            if (useVariable)
            {
                return !StringField.IsNullOrEmpty(caption) ? ("Icon: [Variable=" + StringField.GetStringValue(m_ORKVariable) + "] " + caption)
                  : ((image != null) ? "Icon: " + image.name : "Icon");
            }
            else
            {
                return base.GetEditorName();
            }
        }

    }

}
