﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using System.Collections;
using ORKFramework;
using ORKFramework.Behaviours;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// This abstract class invokes a virtual method OnInventoryChanged when
    /// an ORK combatant's inventory changes. In your subclass, override
    /// OnInventoryChanged. 
    /// 
    /// The ORKInventoryDataSynchronizer overrides this method to update
    /// quest counters that are tied to ORK inventory counts.
    /// </summary>
    public abstract class ORKInventoryMonitor : MonoBehaviour
    {

        protected virtual string purpose { get { return "monitor player's inventory"; } }

        protected Combatant player
        {
            get
            {
                if (ORK.Game.ActiveGroup != null)
                {
                    if (ORK.Game.ActiveGroup.Leader != null)
                    {
                        return ORK.Game.ActiveGroup.Leader;
                    }
                    else
                    {
                        var member = ORK.Game.ActiveGroup.GetFirstNonHiddenMember();
                        return member;
                    }
                }
                return null;
            }
        }

        protected Inventory playerInventory
        {
            get { return (player != null) ? player.Inventory : null; }
        }

        protected virtual IEnumerator Start()
        {
            if (playerInventory == null)
            {
                yield return null; // On NPCs, may need to wait 1 frame for player to appear.
            }
            OnInitialize();
        }

        protected virtual void OnInitialize()
        {
            if (playerInventory == null)
            {
                if (Debug.isDebugBuild) Debug.LogWarning("Quest Machine: " + name + " can't find the player inventory. " + GetType().Name + " will not " + purpose + ".", this);
            }
            else
            {
                if (QuestMachine.debug) Debug.Log("Quest Machine: " + name + " will " + purpose + ".", this);
                playerInventory.Changed -= OnInventoryChanged;
                playerInventory.Changed += OnInventoryChanged;
            }
        }

        protected abstract void OnInventoryChanged();
    }
}