﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using ORKFramework;

namespace PixelCrushers.QuestMachine.ORKSupport
{

    /// <summary>
    /// This subclass of QuestListContainer hooks into ORK's save system.
    /// </summary>
    [AddComponentMenu("Pixel Crushers/Quest Machine/Third Party/ORK Framework/Quest List Container For ORK")]
    public class QuestListContainerForORK : QuestListContainer, IComponentSaveData
    {
        [Tooltip("Tick if using ORKQuestMachineSaveData component on Quest Machine GameObject to save data, in which case there's no need to save here, too.")]
        public bool allowORKQuestMachineSaveDataToSave = false;

        private string m_savedData = null;
        private bool m_destroyed = false;
        private bool m_quitting = false;

        public string GetSaveKey()
        {
            return "QuestMachine" + key;
        }

        public override void OnDestroy()
        {
            if (!m_quitting) m_savedData = RecordData();
            m_destroyed = true;
            base.OnDestroy();
        }

        public virtual void OnApplicationQuit()
        {
            m_quitting = true;
        }

        public DataObject SaveGame()
        {
            if (allowORKQuestMachineSaveDataToSave) return new DataObject();
            DataObject data = new DataObject();
            var s = m_destroyed ? m_savedData : RecordData();
            data.Set("data", s);
            return data;
        }

        public void LoadGame(DataObject data)
        {
            if (allowORKQuestMachineSaveDataToSave) return;
            if (data != null)
            {
                var s = string.Empty;
                data.Get("data", ref s);
                ApplyData(s);
            }
        }

    }
}