﻿// Copyright © Pixel Crushers. All rights reserved.

using UnityEngine;
using ORKFramework;

namespace PixelCrushers.QuestMachine.ORKSupport
{

	/// <summary>
	/// Add to Quest Machine Save System GameObject to save all Quest Machine data.
	/// Typically not required because QuestJournalForORK and QuestGiverForORK also
	/// save into ORK's save system.
	/// </summary>
	public class ORKQuestMachineSaveData : MonoBehaviour, ISaveData
	{
		public bool debug = false;

		// register to the ORK save game handler
		protected virtual void Start()
		{
			ORK.SaveGame.RegisterCustomData("quest_machine", this, false);
			DontDestroyOnLoad(this.gameObject);
		}

		// called when a game is saved
		public DataObject SaveGame()
		{
			DataObject data = new DataObject();
			var serializedData = SaveSystem.Serialize(SaveSystem.RecordSavedGameData());
			if (debug) Debug.Log(GetType().Name + ".SaveGame: " + serializedData);
			data.Set("savedgamedata", serializedData);
			return data;
		}

		// called when a game is loaded
		// depending on the 'beforeSceneLoad' parameter of the registration, 
		// the function will be called either before or after loading the scene.
		public void LoadGame(DataObject data)
		{
			if (data != null)
			{
				string s = null;
				data.Get("savedgamedata", ref s);
				if (string.IsNullOrEmpty(s))
				{
					if (debug) Debug.Log(GetType().Name + ".LoadGame: No data to restore.");
				}
				else
				{
					if (debug) Debug.Log(GetType().Name + ".LoadGame: " + s);
					var savedGameData = SaveSystem.Deserialize<SavedGameData>(s);
					if (savedGameData != null)
					{
						SaveSystem.ApplySavedGameData(savedGameData);
					}
				}
			}
		}
	}
}
